import { Document, Page, Text, View } from "@react-pdf/renderer";
import { TransactionType } from "../Types/Types";
import { colors } from "../../styles";
import StatusTextColor from "../StatusTextColor/StatusTextColor";

type props = {
  transaction: TransactionType;
};
export default function TransactionPDF(props: props) {
  return (
    <Document>
      <Page size={"A4"}>
        <View
          style={{
            alignSelf: "center",
            justifyContent: "center",
            width: "512px",
            backgroundColor: colors.header_color,
            borderRadius: 16,
            margin: "8px",
            padding: "8px",
          }}
        >
          <View style={{ display: "flex", flexDirection: "row" }}>
            <Text
              style={{
                color: colors.font_dark,
                fontSize: 16,
                textAlign: "left",
                flex: 1,
              }}
            >
              Transaction ID: {props.transaction.id}
            </Text>
            <Text
              style={{
                color: colors.font_dark,
                fontSize: 16,
                textAlign: "right",
                flex: 1,
              }}
            >
              {props.transaction.timestamp}
            </Text>
          </View>
          <View style={{ paddingVertical: 8 }}></View>
          <View style={{ display: "flex", flexDirection: "row" }}>
            <View style={{ flex: 1 }}>
              <Text
                style={{
                  color: colors.font_dark,
                  fontSize: 16,
                  textAlign: "left",
                  margin: 0,
                }}
              >
                Borrower: {props.transaction.borrower.name}{" "}
                {`(ID:${props.transaction.borrower.id})`}
              </Text>
              <Text
                style={{
                  color: colors.font_dark,
                  fontSize: 16,
                  textAlign: "left",
                  margin: 0,
                }}
              >
                {`(${props.transaction.borrower.course})`}
              </Text>
              <Text
                style={{
                  color: colors.font_dark,
                  fontSize: 16,
                  textAlign: "left",
                  margin: 0,
                }}
              >
                Teacher: {props.transaction.teacher.name}{" "}
                {`(ID:${props.transaction.teacher.id})`}
              </Text>
              <Text
                style={{
                  color: colors.font_dark,
                  fontSize: 16,
                  textAlign: "left",
                  margin: 0,
                }}
              >
                Subject: {props.transaction.subject}
              </Text>
              <Text
                style={{
                  color: colors.font_dark,
                  fontSize: 16,
                  textAlign: "left",
                  margin: 0,
                  marginTop: 8,
                  flexWrap: "wrap",
                }}
              >
                {props.transaction.remarks}
              </Text>
            </View>
            <View style={{ flex: 1 }}>
              <Text
                style={{
                  color: colors.font_dark,
                  textAlign: "right",
                  fontSize: 16,
                  margin: 0,
                  flexWrap: "wrap",
                }}
              >
                Equipments:
              </Text>
              <View style={{ display: "flex", flexDirection: "column" }}>
                {props.transaction.equipments.map((equipment) => (
                  <Text
                    style={{
                      color: colors.font_dark,
                      textAlign: "right",
                      fontSize: 12,
                      margin: 0,
                      marginTop: 2,
                      flexWrap: "wrap",
                    }}
                  >
                    {` - ${equipment.name} (ID:${equipment.id})`}
                  </Text>
                ))}
              </View>
            </View>
          </View>
          <View style={{ alignContent: "center", justifyContent: "center" }}>
            <Text
              style={{
                color: StatusTextColor(props.transaction.transaction_status),
                textAlign: "center",
                fontSize: 16,
              }}
            >
              {`${props.transaction.transaction_status}`}
            </Text>
          </View>
        </View>
      </Page>
    </Document>
  );
}
